pub struct Tokens<R> { /* private fields */ }Expand description
A queryable, streaming JSON pull parser
Extracts Tokens from an I/O stream of JSON.
Configure the parser then call the next() to parse and return
the next token in the stream.
Implementations
sourceimpl<R: Read> Tokens<R>
impl<R: Read> Tokens<R>
sourcepub fn error(&self) -> Option<JsonError>
pub fn error(&self) -> Option<JsonError>
When the next() returns None due to an error, this will return
the actual error.
sourcepub fn with_mask(self, mask: Mask) -> Self
pub fn with_mask(self, mask: Mask) -> Self
Set the active token mask
Token masks limit the tokens the iterator yields. Use mask::all to
yield all the tokens in the input. Refer to the mask module
documentation for more details.
Note that this is distinct from using Iterator methods like Iterator::skip_while or
Iterator::filter. Using a mask implies the parser will not allocate heap memory for
tokens (specifically string & number tokens) that do not match. Filtering using the
iterator methods happens after the parser has performed any allocations it needs to do.
sourcepub fn dry_run(&mut self) -> Result<DryRun, JsonError>
pub fn dry_run(&mut self) -> Result<DryRun, JsonError>
Parse and validate whatever is left of the JSON stream.
Returns the number of tokens seen as well as the number of tokens that would have matched the active mask.
This method performs no allocations for the tokens it comes across because it operates on raw tokens borrowed from the JSON stream.
If validation is successful, the iterator will be at the end of the stream, so calls to
Tokens::next would return None
If the stream implements Seek, you can “rewind”
and start parsing from the begining again.